==> bitcoin_0.10.1.orig.tar.gz: bitcoin-0.10.1/src/qt/locale/bitcoin_ur_PK.ts <==
<TS language="ur_PK" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>نیا ایڈریس بنائیں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>نیا</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>نقل</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>بند</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>کاپی پتہ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹا</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>چننا</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>بٹوے کی رمزنگاری</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>بٹوا ان لاک</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>خفیہ کشائی کر یںبٹوے کے</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>پاس فریز تبدیل کریں</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Balance:</source>
        <translation>بیلنس:</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ٹائپ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>کو بھیجا</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(N / A)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>تمام</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>آج</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>اس ہفتے</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>اس مہینے</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>پچھلے مہینے</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>اس سال</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>دیگر</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>کو بھیجا</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ٹائپ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This help message</source>
        <translation>یہ مدد کا پیغام</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
</context>
</TS>

==> bitcoin-0.10.3.tar.gz: bitcoin-0.10.3/src/qt/locale/bitcoin_ur_PK.ts <==
<TS language="ur_PK" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>پتہ تبدیل کرے کے لیے دائیاں کلک کریں</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>نیا پتہ بنائیں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>نیا</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>سلیکٹڈ پتے کو کمپوٹر کی عارضی جگہ رکھیں</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>نقل</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>بند</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>کاپی پتہ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سلیکٹڈ پتے کو مٹائیں</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>موجودہ ڈیٹا کو فائیل میں محفوظ کریں</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹائیں</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>کوئین بھیجنے  والے کا پتہ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>چننا</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>جس پتے پر بھیجنے ہیں</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>بٹوے کی رمزنگاری</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>بٹوا ان لاک</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>خفیہ کشائی کر یںبٹوے کے</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>پاس فریز تبدیل کریں</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Balance:</source>
        <translation>بیلنس:</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>چٹ کے بغیر</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ٹائپ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>کو بھیجا</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(N / A)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>تمام</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>آج</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>اس ہفتے</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>اس مہینے</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>پچھلے مہینے</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>اس سال</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>دیگر</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>کو بھیجا</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ٹائپ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>موجودہ ڈیٹا کو فائیل میں محفوظ کریں</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This help message</source>
        <translation>یہ مدد کا پیغام</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
</context>
</TS>
